@@ -4,18 +4,19 @@
  * @output wp-admin/js/post.js
  */
 
- /* global postL10n, ajaxurl, wpAjax, setPostThumbnailL10n, postboxes, pagenow, tinymce, alert, deleteUserSetting */
+ /* global ajaxurl, wpAjax, postboxes, pagenow, tinymce, alert, deleteUserSetting, ClipboardJS */
  /* global theList:true, theExtraList:true, getUserSetting, setUserSetting, commentReply, commentsBox */
  /* global WPSetThumbnailHTML, wptitlehint */
 
-// Backwards compatibility: prevent fatal errors.
+// Backward compatibility: prevent fatal errors.
 window.makeSlugeditClickable = window.editPermalink = function(){};
 
 // Make sure the wp object exists.
 window.wp = window.wp || {};
 
 ( function( $ ) {
-	var titleHasFocus = false;
+	var titleHasFocus = false,
+		__ = wp.i18n.__;
 
 	/**
 	 * Control loading of comments on the post and term edit pages.
@@ -29,13 +30,13 @@ window.wp = window.wp || {};
 		st : 0,
 
 		/**
-		 * Fetch comments using AJAX and display them in the box.
+		 * Fetch comments using Ajax and display them in the box.
 		 *
 		 * @memberof commentsBox
 		 *
-		 * @param {int} total Total number of comments for this post.
-		 * @param {int} num   Optional. Number of comments to fetch, defaults to 20.
-		 * @returns {boolean} Always returns false.
+		 * @param {number} total Total number of comments for this post.
+		 * @param {number} num   Optional. Number of comments to fetch, defaults to 20.
+		 * @return {boolean} Always returns false.
 		 */
 		get : function(total, num) {
 			var st = this.st, data;
@@ -67,17 +68,17 @@ window.wp = window.wp || {};
 						$('#the-comment-list').append( r.responses[0].data );
 
 						theList = theExtraList = null;
-						$( 'a[className*=\':\']' ).unbind();
+						$( 'a[className*=\':\']' ).off();
 
 						// If the offset is over the total number of comments we cannot fetch any more, so hide the button.
 						if ( commentsBox.st > commentsBox.total )
 							$('#show-comments').hide();
 						else
-							$('#show-comments').show().children('a').html(postL10n.showcomm);
+							$('#show-comments').show().children('a').text( __( 'Show more comments' ) );
 
 						return;
 					} else if ( 1 == r ) {
-						$('#show-comments').html(postL10n.endcomm);
+						$('#show-comments').text( __( 'No more comments found.' ) );
 						return;
 					}
 
@@ -91,9 +92,9 @@ window.wp = window.wp || {};
 		/**
 		 * Load the next batch of comments.
 		 *
-		 * @param {int} total Total number of comments to load.
-		 *
 		 * @memberof commentsBox
+		 *
+		 * @param {number} total Total number of comments to load.
 		 */
 		load: function(total){
 			this.st = jQuery('#the-comment-list tr.comment:visible').length;
@@ -115,7 +116,7 @@ window.wp = window.wp || {};
 	/**
 	 * Set the Image ID of the Featured Image
 	 *
-	 * @param {int} id The post_id of the image to use as Featured Image.
+	 * @param {number} id The post_id of the image to use as Featured Image.
 	 *
 	 * @global
 	 */
@@ -134,21 +135,26 @@ window.wp = window.wp || {};
 	 * @global
 	 */
 	window.WPRemoveThumbnail = function(nonce){
-		$.post(ajaxurl, {
-			action: 'set-post-thumbnail', post_id: $( '#post_ID' ).val(), thumbnail_id: -1, _ajax_nonce: nonce, cookie: encodeURIComponent( document.cookie )
-		},
+		$.post(
+			ajaxurl, {
+				action: 'set-post-thumbnail',
+				post_id: $( '#post_ID' ).val(),
+				thumbnail_id: -1,
+				_ajax_nonce: nonce,
+				cookie: encodeURIComponent( document.cookie )
+			},
 			/**
 			 * Handle server response
 			 *
 			 * @param {string} str Response, will be '0' when an error occurred otherwise contains link to add Featured Image.
 			 */
 			function(str){
-			if ( str == '0' ) {
-				alert( setPostThumbnailL10n.error );
-			} else {
-				WPSetThumbnailHTML(str);
+				if ( str == '0' ) {
+					alert( __( 'Could not set that as the thumbnail image. Try a different attachment.' ) );
+				} else {
+					WPSetThumbnailHTML(str);
+				}
 			}
-		}
 		);
 	};
 
@@ -200,12 +206,21 @@ window.wp = window.wp || {};
 					}
 
 					if ( received.lock_error.avatar_src ) {
-						avatar = $( '<img class="avatar avatar-64 photo" width="64" height="64" alt="" />' ).attr( 'src', received.lock_error.avatar_src.replace( /&amp;/g, '&' ) );
+						avatar = $( '<img />', {
+							'class': 'avatar avatar-64 photo',
+							width: 64,
+							height: 64,
+							alt: '',
+							src: received.lock_error.avatar_src,
+							srcset: received.lock_error.avatar_src_2x ?
+								received.lock_error.avatar_src_2x + ' 2x' :
+								undefined
+						} );
 						wrap.find('div.post-locked-avatar').empty().append( avatar );
 					}
 
 					wrap.show().find('.currently-editing').text( received.lock_error.text );
-					wrap.find('.wp-tab-first').focus();
+					wrap.find('.wp-tab-first').trigger( 'focus' );
 				}
 			} else if ( received.new_lock ) {
 				$('#active_post_lock').val( received.new_lock );
@@ -252,7 +267,9 @@ window.wp = window.wp || {};
 		timeout = window.setTimeout( function(){ check = true; }, 300000 );
 	}
 
-	$(document).on( 'heartbeat-send.wp-refresh-nonces', function( e, data ) {
+	$( function() {
+		schedule();
+	}).on( 'heartbeat-send.wp-refresh-nonces', function( e, data ) {
 		var post_id,
 			$authCheck = $('#wp-auth-check-wrap');
 
@@ -278,17 +295,14 @@ window.wp = window.wp || {};
 			if ( nonces.heartbeatNonce )
 				window.heartbeatSettings.nonce = nonces.heartbeatNonce;
 		}
-	}).ready( function() {
-		schedule();
 	});
 }(jQuery));
 
 /**
  * All post and postbox controls and functionality.
  */
-jQuery(document).ready( function($) {
+jQuery( function($) {
 	var stamp, visibility, $submitButtons, updateVisibility, updateText,
-		sticky = '',
 		$textarea = $('#content'),
 		$document = $(document),
 		postId = $('#post_ID').val() || 0,
@@ -297,7 +311,10 @@ jQuery(document).ready( function($) {
 		$postVisibilitySelect = $('#post-visibility-select'),
 		$timestampdiv = $('#timestampdiv'),
 		$postStatusSelect = $('#post-status-select'),
-		isMac = window.navigator.platform ? window.navigator.platform.indexOf( 'Mac' ) !== -1 : false;
+		isMac = window.navigator.platform ? window.navigator.platform.indexOf( 'Mac' ) !== -1 : false,
+		copyAttachmentURLClipboard = new ClipboardJS( '.copy-attachment-url.edit-media' ),
+		copyAttachmentURLSuccessTimeout,
+		__ = wp.i18n.__, _x = wp.i18n._x;
 
 	postboxes.add_postbox_toggles(pagenow);
 
@@ -309,24 +326,24 @@ jQuery(document).ready( function($) {
 
 	// Post locks: contain focus inside the dialog. If the dialog is shown, focus the first item.
 	$('#post-lock-dialog .notification-dialog').on( 'keydown', function(e) {
-		// Don't do anything when [tab] is pressed.
+		// Don't do anything when [Tab] is pressed.
 		if ( e.which != 9 )
 			return;
 
 		var target = $(e.target);
 
-		// [shift] + [tab] on first tab cycles back to last tab.
+		// [Shift] + [Tab] on first tab cycles back to last tab.
 		if ( target.hasClass('wp-tab-first') && e.shiftKey ) {
-			$(this).find('.wp-tab-last').focus();
+			$(this).find('.wp-tab-last').trigger( 'focus' );
 			e.preventDefault();
-		// [tab] on last tab cycles back to first tab.
+		// [Tab] on last tab cycles back to first tab.
 		} else if ( target.hasClass('wp-tab-last') && ! e.shiftKey ) {
-			$(this).find('.wp-tab-first').focus();
+			$(this).find('.wp-tab-first').trigger( 'focus' );
 			e.preventDefault();
 		}
-	}).filter(':visible').find('.wp-tab-first').focus();
+	}).filter(':visible').find('.wp-tab-first').trigger( 'focus' );
 
-	// Set the heartbeat interval to 15 sec. if post lock dialogs are enabled.
+	// Set the heartbeat interval to 15 seconds if post lock dialogs are enabled.
 	if ( wp.heartbeat && $('#post-lock-dialog').length ) {
 		wp.heartbeat.interval( 15 );
 	}
@@ -385,7 +402,7 @@ jQuery(document).ready( function($) {
 		});
 	});
 
-	// Submit the form saving a draft or an autosave, and show a preview in a new tab
+	// Submit the form saving a draft or an autosave, and show a preview in a new tab.
 	$('#post-preview').on( 'click.post-preview', function( event ) {
 		var $this = $(this),
 			$form = $('form#post'),
@@ -404,7 +421,7 @@ jQuery(document).ready( function($) {
 		}
 
 		$previewField.val('dopreview');
-		$form.attr( 'target', target ).submit().attr( 'target', '' );
+		$form.attr( 'target', target ).trigger( 'submit' ).attr( 'target', '' );
 
 		// Workaround for WebKit bug preventing a form submitting twice to the same action.
 		// https://bugs.webkit.org/show_bug.cgi?id=28633
@@ -427,7 +444,7 @@ jQuery(document).ready( function($) {
 			if ( editor && ! editor.isHidden() ) {
 				editor.focus();
 			} else if ( $textarea.length ) {
-				$textarea.focus();
+				$textarea.trigger( 'focus' );
 			} else {
 				return;
 			}
@@ -438,7 +455,7 @@ jQuery(document).ready( function($) {
 
 	// Auto save new posts after a title is typed.
 	if ( $( '#auto_draft' ).val() ) {
-		$( '#title' ).blur( function() {
+		$( '#title' ).on( 'blur', function() {
 			var cancel;
 
 			if ( ! this.value || $('#edit-slug-box > *').length ) {
@@ -465,7 +482,7 @@ jQuery(document).ready( function($) {
 			$submitButtons.removeClass( 'disabled' );
 		}
 	}).on( 'before-autosave.edit-post', function() {
-		$( '.autosave-message' ).text( postL10n.savingText );
+		$( '.autosave-message' ).text( __( 'Saving Draft…' ) );
 	}).on( 'after-autosave.edit-post', function( event, data ) {
 		$( '.autosave-message' ).text( data.message );
 
@@ -478,15 +495,23 @@ jQuery(document).ready( function($) {
 	 * When the user is trying to load another page, or reloads current page
 	 * show a confirmation dialog when there are unsaved changes.
 	 */
-	$(window).on( 'beforeunload.edit-post', function() {
-		var editor = typeof tinymce !== 'undefined' && tinymce.get('content');
+	$( window ).on( 'beforeunload.edit-post', function( event ) {
+		var editor  = window.tinymce && window.tinymce.get( 'content' );
+		var changed = false;
 
-		if ( ( editor && ! editor.isHidden() && editor.isDirty() ) ||
-			( wp.autosave && wp.autosave.server.postChanged() ) ) {
-
-			return postL10n.saveAlert;
+		if ( wp.autosave ) {
+			changed = wp.autosave.server.postChanged();
+		} else if ( editor ) {
+			changed = ( ! editor.isHidden() && editor.isDirty() );
 		}
-	}).on( 'unload.edit-post', function( event ) {
+
+		if ( changed ) {
+			event.preventDefault();
+			// The return string is needed for browser compat.
+			// See https://developer.mozilla.org/en-US/docs/Web/API/Window/beforeunload_event.
+			return __( 'The changes you made will be lost if you navigate away from this page.' );
+		}
+	}).on( 'pagehide.edit-post', function( event ) {
 		if ( ! releaseLock ) {
 			return;
 		}
@@ -534,7 +559,7 @@ jQuery(document).ready( function($) {
 		});
 	});
 
-	// Multiple Taxonomies.
+	// Multiple taxonomies.
 	if ( $('#tagsdiv-post_tag').length ) {
 		window.tagBox && window.tagBox.init();
 	} else {
@@ -559,8 +584,8 @@ jQuery(document).ready( function($) {
 			settingName = 'cats';
 		}
 
-		// TODO: move to jQuery 1.3+, support for multiple hierarchical taxonomies, see wp-lists.js
-		$('a', '#' + taxonomy + '-tabs').click( function( e ) {
+		// @todo Move to jQuery 1.3+, support for multiple hierarchical taxonomies, see wp-lists.js.
+		$('a', '#' + taxonomy + '-tabs').on( 'click', function( e ) {
 			e.preventDefault();
 			var t = $(this).attr('href');
 			$(this).parent().addClass('tabs').siblings('li').removeClass('tabs');
@@ -574,24 +599,24 @@ jQuery(document).ready( function($) {
 		});
 
 		if ( getUserSetting( settingName ) )
-			$('a[href="#' + taxonomy + '-pop"]', '#' + taxonomy + '-tabs').click();
+			$('a[href="#' + taxonomy + '-pop"]', '#' + taxonomy + '-tabs').trigger( 'click' );
 
 		// Add category button controls.
 		$('#new' + taxonomy).one( 'focus', function() {
 			$( this ).val( '' ).removeClass( 'form-input-tip' );
 		});
 
-		// On [enter] submit the taxonomy.
-		$('#new' + taxonomy).keypress( function(event){
+		// On [Enter] submit the taxonomy.
+		$('#new' + taxonomy).on( 'keypress', function(event){
 			if( 13 === event.keyCode ) {
 				event.preventDefault();
-				$('#' + taxonomy + '-add-submit').click();
+				$('#' + taxonomy + '-add-submit').trigger( 'click' );
 			}
 		});
 
 		// After submitting a new taxonomy, re-focus the input field.
-		$('#' + taxonomy + '-add-submit').click( function() {
-			$('#new' + taxonomy).focus();
+		$('#' + taxonomy + '-add-submit').on( 'click', function() {
+			$('#new' + taxonomy).trigger( 'focus' );
 		});
 
 		/**
@@ -599,7 +624,7 @@ jQuery(document).ready( function($) {
 		 *
 		 * @param {Object} s Taxonomy object which will be added.
 		 *
-		 * @returns {Object}
+		 * @return {Object}
 		 */
 		catAddBefore = function( s ) {
 			if ( !$('#new'+taxonomy).val() ) {
@@ -620,7 +645,7 @@ jQuery(document).ready( function($) {
 		 * @param {Object} r Response.
 		 * @param {Object} s Taxonomy data.
 		 *
-		 * @returns void
+		 * @return {void}
 		 */
 		catAddAfter = function( r, s ) {
 			var sup, drop = $('#new'+taxonomy+'_parent');
@@ -640,21 +665,25 @@ jQuery(document).ready( function($) {
 		});
 
 		// Add new taxonomy button toggles input form visibility.
-		$('#' + taxonomy + '-add-toggle').click( function( e ) {
+		$('#' + taxonomy + '-add-toggle').on( 'click', function( e ) {
 			e.preventDefault();
 			$('#' + taxonomy + '-adder').toggleClass( 'wp-hidden-children' );
-			$('a[href="#' + taxonomy + '-all"]', '#' + taxonomy + '-tabs').click();
-			$('#new'+taxonomy).focus();
+			$('a[href="#' + taxonomy + '-all"]', '#' + taxonomy + '-tabs').trigger( 'click' );
+			$('#new'+taxonomy).trigger( 'focus' );
 		});
 
 		// Sync checked items between "All {taxonomy}" and "Most used" lists.
-		$('#' + taxonomy + 'checklist, #' + taxonomy + 'checklist-pop').on( 'click', 'li.popular-category > label input[type="checkbox"]', function() {
-			var t = $(this), c = t.is(':checked'), id = t.val();
-			if ( id && t.parents('#taxonomy-'+taxonomy).length )
-				$('#in-' + taxonomy + '-' + id + ', #in-popular-' + taxonomy + '-' + id).prop( 'checked', c );
-		});
+		$('#' + taxonomy + 'checklist, #' + taxonomy + 'checklist-pop').on(
+			'click',
+			'li.popular-category > label input[type="checkbox"]',
+			function() {
+				var t = $(this), c = t.is(':checked'), id = t.val();
+				if ( id && t.parents('#taxonomy-'+taxonomy).length )
+					$('#in-' + taxonomy + '-' + id + ', #in-popular-' + taxonomy + '-' + id).prop( 'checked', c );
+			}
+		);
 
-	}); // end cats
+	}); // End cats.
 
 	// Custom Fields postbox.
 	if ( $('#postcustom').length ) {
@@ -666,7 +695,7 @@ jQuery(document).ready( function($) {
 			 *
 			 * @param {Object} s Request object.
 			 *
-			 * @returns {Object} Data modified with post_ID attached.
+			 * @return {Object} Data modified with post_ID attached.
 			 */
 			addBefore: function( s ) {
 				s.data += '&post_id=' + $('#post_ID').val();
@@ -695,7 +724,7 @@ jQuery(document).ready( function($) {
 		 *
 		 * @ignore
 		 *
-		 * @returns void
+		 * @return {void}
 		 */
 		updateVisibility = function() {
 			// Show sticky for public posts.
@@ -719,7 +748,7 @@ jQuery(document).ready( function($) {
 		 *
 		 * @ignore
 		 *
-		 * @returns {boolean} False when an invalid timestamp has been selected, otherwise True.
+		 * @return {boolean} False when an invalid timestamp has been selected, otherwise True.
 		 */
 		updateText = function() {
 
@@ -731,11 +760,28 @@ jQuery(document).ready( function($) {
 				mm = $('#mm').val(), jj = $('#jj').val(), hh = $('#hh').val(), mn = $('#mn').val();
 
 			attemptedDate = new Date( aa, mm - 1, jj, hh, mn );
-			originalDate = new Date( $('#hidden_aa').val(), $('#hidden_mm').val() -1, $('#hidden_jj').val(), $('#hidden_hh').val(), $('#hidden_mn').val() );
-			currentDate = new Date( $('#cur_aa').val(), $('#cur_mm').val() -1, $('#cur_jj').val(), $('#cur_hh').val(), $('#cur_mn').val() );
+			originalDate = new Date(
+				$('#hidden_aa').val(),
+				$('#hidden_mm').val() -1,
+				$('#hidden_jj').val(),
+				$('#hidden_hh').val(),
+				$('#hidden_mn').val()
+			);
+			currentDate = new Date(
+				$('#cur_aa').val(),
+				$('#cur_mm').val() -1,
+				$('#cur_jj').val(),
+				$('#cur_hh').val(),
+				$('#cur_mn').val()
+			);
 
 			// Catch unexpected date problems.
-			if ( attemptedDate.getFullYear() != aa || (1 + attemptedDate.getMonth()) != mm || attemptedDate.getDate() != jj || attemptedDate.getMinutes() != mn ) {
+			if (
+				attemptedDate.getFullYear() != aa ||
+				(1 + attemptedDate.getMonth()) != mm ||
+				attemptedDate.getDate() != jj ||
+				attemptedDate.getMinutes() != mn
+			) {
 				$timestampdiv.find('.timestamp-wrap').addClass('form-invalid');
 				return false;
 			} else {
@@ -743,15 +789,15 @@ jQuery(document).ready( function($) {
 			}
 
 			// Determine what the publish should be depending on the date and post status.
-			if ( attemptedDate > currentDate && $('#original_post_status').val() != 'future' ) {
-				publishOn = postL10n.publishOnFuture;
-				$('#publish').val( postL10n.schedule );
+			if ( attemptedDate > currentDate ) {
+				publishOn = __( 'Schedule for:' );
+				$('#publish').val( _x( 'Schedule', 'post action/button label' ) );
 			} else if ( attemptedDate <= currentDate && $('#original_post_status').val() != 'publish' ) {
-				publishOn = postL10n.publishOn;
-				$('#publish').val( postL10n.publish );
+				publishOn = __( 'Publish on:' );
+				$('#publish').val( __( 'Publish' ) );
 			} else {
-				publishOn = postL10n.publishOnPast;
-				$('#publish').val( postL10n.update );
+				publishOn = __( 'Published on:' );
+				$('#publish').val( __( 'Update' ) );
 			}
 
 			// If the date is the same, set it to trigger update events.
@@ -761,7 +807,8 @@ jQuery(document).ready( function($) {
 			} else {
 				$('#timestamp').html(
 					'\n' + publishOn + ' <b>' +
-					postL10n.dateFormat
+					// translators: 1: Month, 2: Day, 3: Year, 4: Hour, 5: Minute.
+					__( '%1$s %2$s, %3$s at %4$s:%5$s' )
 						.replace( '%1$s', $( 'option[value="' + mm + '"]', '#mm' ).attr( 'data-text' ) )
 						.replace( '%2$s', parseInt( jj, 10 ) )
 						.replace( '%3$s', aa )
@@ -773,11 +820,11 @@ jQuery(document).ready( function($) {
 
 			// Add "privately published" to post status when applies.
 			if ( $postVisibilitySelect.find('input:radio:checked').val() == 'private' ) {
-				$('#publish').val( postL10n.update );
+				$('#publish').val( __( 'Update' ) );
 				if ( 0 === optPublish.length ) {
-					postStatus.append('<option value="publish">' + postL10n.privatelyPublished + '</option>');
+					postStatus.append('<option value="publish">' + __( 'Privately Published' ) + '</option>');
 				} else {
-					optPublish.html( postL10n.privatelyPublished );
+					optPublish.html( __( 'Privately Published' ) );
 				}
 				$('option[value="publish"]', postStatus).prop('selected', true);
 				$('#misc-publishing-actions .edit-post-status').hide();
@@ -788,83 +835,97 @@ jQuery(document).ready( function($) {
 						postStatus.val($('#hidden_post_status').val());
 					}
 				} else {
-					optPublish.html( postL10n.published );
+					optPublish.html( __( 'Published' ) );
 				}
 				if ( postStatus.is(':hidden') )
 					$('#misc-publishing-actions .edit-post-status').show();
 			}
 
 			// Update "Status:" to currently selected status.
-			$('#post-status-display').html($('option:selected', postStatus).text());
+			$('#post-status-display').text(
+				// Remove any potential tags from post status text.
+				wp.sanitize.stripTagsAndEncodeText( $('option:selected', postStatus).text() )
+			);
 
 			// Show or hide the "Save Draft" button.
-			if ( $('option:selected', postStatus).val() == 'private' || $('option:selected', postStatus).val() == 'publish' ) {
+			if (
+				$('option:selected', postStatus).val() == 'private' ||
+				$('option:selected', postStatus).val() == 'publish'
+			) {
 				$('#save-post').hide();
 			} else {
 				$('#save-post').show();
 				if ( $('option:selected', postStatus).val() == 'pending' ) {
-					$('#save-post').show().val( postL10n.savePending );
+					$('#save-post').show().val( __( 'Save as Pending' ) );
 				} else {
-					$('#save-post').show().val( postL10n.saveDraft );
+					$('#save-post').show().val( __( 'Save Draft' ) );
 				}
 			}
 			return true;
 		};
 
 		// Show the visibility options and hide the toggle button when opened.
-		$( '#visibility .edit-visibility').click( function( e ) {
+		$( '#visibility .edit-visibility').on( 'click', function( e ) {
 			e.preventDefault();
 			if ( $postVisibilitySelect.is(':hidden') ) {
 				updateVisibility();
 				$postVisibilitySelect.slideDown( 'fast', function() {
-					$postVisibilitySelect.find( 'input[type="radio"]' ).first().focus();
+					$postVisibilitySelect.find( 'input[type="radio"]' ).first().trigger( 'focus' );
 				} );
 				$(this).hide();
 			}
 		});
 
 		// Cancel visibility selection area and hide it from view.
-		$postVisibilitySelect.find('.cancel-post-visibility').click( function( event ) {
+		$postVisibilitySelect.find('.cancel-post-visibility').on( 'click', function( event ) {
 			$postVisibilitySelect.slideUp('fast');
 			$('#visibility-radio-' + $('#hidden-post-visibility').val()).prop('checked', true);
 			$('#post_password').val($('#hidden-post-password').val());
 			$('#sticky').prop('checked', $('#hidden-post-sticky').prop('checked'));
 			$('#post-visibility-display').html(visibility);
-			$('#visibility .edit-visibility').show().focus();
+			$('#visibility .edit-visibility').show().trigger( 'focus' );
 			updateText();
 			event.preventDefault();
 		});
 
 		// Set the selected visibility as current.
-		$postVisibilitySelect.find('.save-post-visibility').click( function( event ) { // crazyhorse - multiple ok cancels
+		$postVisibilitySelect.find('.save-post-visibility').on( 'click', function( event ) { // Crazyhorse - multiple OK cancels.
+			var visibilityLabel = '', selectedVisibility = $postVisibilitySelect.find('input:radio:checked').val();
+
 			$postVisibilitySelect.slideUp('fast');
-			$('#visibility .edit-visibility').show().focus();
+			$('#visibility .edit-visibility').show().trigger( 'focus' );
 			updateText();
 
-			if ( $postVisibilitySelect.find('input:radio:checked').val() != 'public' ) {
+			if ( 'public' !== selectedVisibility ) {
 				$('#sticky').prop('checked', false);
 			}
 
-			if ( $('#sticky').prop('checked') ) {
-				sticky = 'Sticky';
-			} else {
-				sticky = '';
+			switch ( selectedVisibility ) {
+				case 'public':
+					visibilityLabel = $( '#sticky' ).prop( 'checked' ) ? __( 'Public, Sticky' ) : __( 'Public' );
+					break;
+				case 'private':
+					visibilityLabel = __( 'Private' );
+					break;
+				case 'password':
+					visibilityLabel = __( 'Password Protected' );
+					break;
 			}
 
-			$('#post-visibility-display').html(	postL10n[ $postVisibilitySelect.find('input:radio:checked').val() + sticky ]	);
+			$('#post-visibility-display').text( visibilityLabel );
 			event.preventDefault();
 		});
 
 		// When the selection changes, update labels.
-		$postVisibilitySelect.find('input:radio').change( function() {
+		$postVisibilitySelect.find('input:radio').on( 'change', function() {
 			updateVisibility();
 		});
 
 		// Edit publish time click.
-		$timestampdiv.siblings('a.edit-timestamp').click( function( event ) {
+		$timestampdiv.siblings('a.edit-timestamp').on( 'click', function( event ) {
 			if ( $timestampdiv.is( ':hidden' ) ) {
 				$timestampdiv.slideDown( 'fast', function() {
-					$( 'input, select', $timestampdiv.find( '.timestamp-wrap' ) ).first().focus();
+					$( 'input, select', $timestampdiv.find( '.timestamp-wrap' ) ).first().trigger( 'focus' );
 				} );
 				$(this).hide();
 			}
@@ -872,8 +933,8 @@ jQuery(document).ready( function($) {
 		});
 
 		// Cancel editing the publish time and hide the settings.
-		$timestampdiv.find('.cancel-timestamp').click( function( event ) {
-			$timestampdiv.slideUp('fast').siblings('a.edit-timestamp').show().focus();
+		$timestampdiv.find('.cancel-timestamp').on( 'click', function( event ) {
+			$timestampdiv.slideUp('fast').siblings('a.edit-timestamp').show().trigger( 'focus' );
 			$('#mm').val($('#hidden_mm').val());
 			$('#jj').val($('#hidden_jj').val());
 			$('#aa').val($('#hidden_aa').val());
@@ -884,10 +945,10 @@ jQuery(document).ready( function($) {
 		});
 
 		// Save the changed timestamp.
-		$timestampdiv.find('.save-timestamp').click( function( event ) { // crazyhorse - multiple ok cancels
+		$timestampdiv.find('.save-timestamp').on( 'click', function( event ) { // Crazyhorse - multiple OK cancels.
 			if ( updateText() ) {
 				$timestampdiv.slideUp('fast');
-				$timestampdiv.siblings('a.edit-timestamp').show().focus();
+				$timestampdiv.siblings('a.edit-timestamp').show().trigger( 'focus' );
 			}
 			event.preventDefault();
 		});
@@ -907,10 +968,10 @@ jQuery(document).ready( function($) {
 		});
 
 		// Post Status edit click.
-		$postStatusSelect.siblings('a.edit-post-status').click( function( event ) {
+		$postStatusSelect.siblings('a.edit-post-status').on( 'click', function( event ) {
 			if ( $postStatusSelect.is( ':hidden' ) ) {
 				$postStatusSelect.slideDown( 'fast', function() {
-					$postStatusSelect.find('select').focus();
+					$postStatusSelect.find('select').trigger( 'focus' );
 				} );
 				$(this).hide();
 			}
@@ -918,15 +979,15 @@ jQuery(document).ready( function($) {
 		});
 
 		// Save the Post Status changes and hide the options.
-		$postStatusSelect.find('.save-post-status').click( function( event ) {
-			$postStatusSelect.slideUp( 'fast' ).siblings( 'a.edit-post-status' ).show().focus();
+		$postStatusSelect.find('.save-post-status').on( 'click', function( event ) {
+			$postStatusSelect.slideUp( 'fast' ).siblings( 'a.edit-post-status' ).show().trigger( 'focus' );
 			updateText();
 			event.preventDefault();
 		});
 
 		// Cancel Post Status editing and hide the options.
-		$postStatusSelect.find('.cancel-post-status').click( function( event ) {
-			$postStatusSelect.slideUp( 'fast' ).siblings( 'a.edit-post-status' ).show().focus();
+		$postStatusSelect.find('.cancel-post-status').on( 'click', function( event ) {
+			$postStatusSelect.slideUp( 'fast' ).siblings( 'a.edit-post-status' ).show().trigger( 'focus' );
 			$('#post_status').val( $('#hidden_post_status').val() );
 			updateText();
 			event.preventDefault();
@@ -935,14 +996,14 @@ jQuery(document).ready( function($) {
 
 	/**
 	 * Handle the editing of the post_name. Create the required HTML elements and
-	 * update the changes via AJAX.
+	 * update the changes via Ajax.
 	 *
 	 * @global
 	 *
-	 * @returns void
+	 * @return {void}
 	 */
 	function editPermalink() {
-		var i, slug_value,
+		var i, slug_value, slug_label,
 			$el, revert_e,
 			c = 0,
 			real_slug = $('#post_name'),
@@ -964,14 +1025,17 @@ jQuery(document).ready( function($) {
 		$el = $( '#editable-post-name' );
 		revert_e = $el.html();
 
-		buttons.html( '<button type="button" class="save button button-small">' + postL10n.ok + '</button> <button type="button" class="cancel button-link">' + postL10n.cancel + '</button>' );
+		buttons.html(
+			'<button type="button" class="save button button-small">' + __( 'OK' ) + '</button> ' +
+			'<button type="button" class="cancel button-link">' + __( 'Cancel' ) + '</button>'
+		);
 
 		// Save permalink changes.
-		buttons.children( '.save' ).click( function() {
+		buttons.children( '.save' ).on( 'click', function() {
 			var new_slug = $el.children( 'input' ).val();
 
 			if ( new_slug == $('#editable-post-name-full').text() ) {
-				buttons.children('.cancel').click();
+				buttons.children('.cancel').trigger( 'click' );
 				return;
 			}
 
@@ -996,20 +1060,20 @@ jQuery(document).ready( function($) {
 					buttons.html(buttonsOrig);
 					permalink.html(permalinkOrig);
 					real_slug.val(new_slug);
-					$( '.edit-slug' ).focus();
-					wp.a11y.speak( postL10n.permalinkSaved );
+					$( '.edit-slug' ).trigger( 'focus' );
+					wp.a11y.speak( __( 'Permalink saved' ) );
 				}
 			);
 		});
 
 		// Cancel editing of permalink.
-		buttons.children( '.cancel' ).click( function() {
+		buttons.children( '.cancel' ).on( 'click', function() {
 			$('#view-post-btn').show();
 			$el.html(revert_e);
 			buttons.html(buttonsOrig);
 			permalink.html(permalinkOrig);
 			real_slug.val(revert_slug);
-			$( '.edit-slug' ).focus();
+			$( '.edit-slug' ).trigger( 'focus' );
 		});
 
 		// If more than 1/4th of 'full' is '%', make it empty.
@@ -1018,21 +1082,25 @@ jQuery(document).ready( function($) {
 				c++;
 		}
 		slug_value = ( c > full.length / 4 ) ? '' : full;
+		slug_label = __( 'URL Slug' );
 
-		$el.html( '<input type="text" id="new-post-slug" value="' + slug_value + '" autocomplete="off" />' ).children( 'input' ).keydown( function( e ) {
+		$el.html(
+			'<label for="new-post-slug" class="screen-reader-text">' + slug_label + '</label>' +
+			'<input type="text" id="new-post-slug" value="' + slug_value + '" autocomplete="off" spellcheck="false" />'
+		).children( 'input' ).on( 'keydown', function( e ) {
 			var key = e.which;
-			// On [enter], just save the new slug, don't save the post.
+			// On [Enter], just save the new slug, don't save the post.
 			if ( 13 === key ) {
 				e.preventDefault();
-				buttons.children( '.save' ).click();
+				buttons.children( '.save' ).trigger( 'click' );
 			}
-			// On [esc] cancel the editing.
+			// On [Esc] cancel the editing.
 			if ( 27 === key ) {
-				buttons.children( '.cancel' ).click();
+				buttons.children( '.cancel' ).trigger( 'click' );
 			}
-		} ).keyup( function() {
+		} ).on( 'keyup', function() {
 			real_slug.val( this.value );
-		}).focus();
+		}).trigger( 'focus' );
 	}
 
 	$( '#titlediv' ).on( 'click', '.edit-slug', function() {
@@ -1049,7 +1117,7 @@ jQuery(document).ready( function($) {
 	 *
 	 * @global
 	 *
-	 * @returns void
+	 * @return {void}
 	 */
 	window.wptitlehint = function( id ) {
 		id = id || 'title';
@@ -1124,7 +1192,7 @@ jQuery(document).ready( function($) {
 
 				height = parseInt( $('#content_ifr').css('height'), 10 ) + toolbarHeight - 28;
 			} else {
-				$textarea.focus();
+				$textarea.trigger( 'focus' );
 				height = parseInt( $textarea.css('height'), 10 );
 			}
 
@@ -1147,7 +1215,7 @@ jQuery(document).ready( function($) {
 			} else {
 				mce = false;
 				offset = $textarea.height() - event.pageY;
-				$textarea.blur();
+				$textarea.trigger( 'blur' );
 			}
 
 			$document.on( 'mousemove.wp-editor-resize', dragging )
@@ -1171,7 +1239,7 @@ jQuery(document).ready( function($) {
 			}
 		});
 
-		// When changing page template, change the editor body class
+		// When changing page template, change the editor body class.
 		$( '#page_template' ).on( 'change.set-editor-class', function() {
 			var editor, body, pageTemplate = $( this ).val() || '';
 
@@ -1189,11 +1257,16 @@ jQuery(document).ready( function($) {
 
 	}
 
-	// Save on pressing [ctrl]/[command] + [s] in the Text editor.
+	// Save on pressing [Ctrl]/[Command] + [S] in the Text editor.
 	$textarea.on( 'keydown.wp-autosave', function( event ) {
-		// Key [s] has code 83.
+		// Key [S] has code 83.
 		if ( event.which === 83 ) {
-			if ( event.shiftKey || event.altKey || ( isMac && ( ! event.metaKey || event.ctrlKey ) ) || ( ! isMac && ! event.ctrlKey ) ) {
+			if (
+				event.shiftKey ||
+				event.altKey ||
+				( isMac && ( ! event.metaKey || event.ctrlKey ) ) ||
+				( ! isMac && ! event.ctrlKey )
+			) {
 				return;
 			}
 
@@ -1214,7 +1287,38 @@ jQuery(document).ready( function($) {
 			window.history.replaceState( null, null, location );
 		});
 	}
-});
+
+	/**
+	 * Copies the attachment URL in the Edit Media page to the clipboard.
+	 *
+	 * @since 5.5.0
+	 *
+	 * @param {MouseEvent} event A click event.
+	 *
+	 * @return {void}
+	 */
+	copyAttachmentURLClipboard.on( 'success', function( event ) {
+		var triggerElement = $( event.trigger ),
+			successElement = $( '.success', triggerElement.closest( '.copy-to-clipboard-container' ) );
+
+		// Clear the selection and move focus back to the trigger.
+		event.clearSelection();
+		// Handle ClipboardJS focus bug, see https://github.com/zenorocha/clipboard.js/issues/680
+		triggerElement.trigger( 'focus' );
+
+		// Show success visual feedback.
+		clearTimeout( copyAttachmentURLSuccessTimeout );
+		successElement.removeClass( 'hidden' );
+
+		// Hide success visual feedback after 3 seconds since last success.
+		copyAttachmentURLSuccessTimeout = setTimeout( function() {
+			successElement.addClass( 'hidden' );
+		}, 3000 );
+
+		// Handle success audible feedback.
+		wp.a11y.speak( __( 'The file URL has been copied to your clipboard' ) );
+	} );
+} );
 
 /**
  * TinyMCE word count display
